import java.awt.*;
import java.awt.event.*;

/**
 *  MySecondFrame class
 *
 * <p>
 * A sample frame to illustrate the placing of GUI objects and event handling.
 */

class MySecondFrame extends Frame implements ActionListener
{

//----------------------------------
//    Data Members
//----------------------------------
    
    /**
     * Default frame width
     */
    private static final int FRAME_WIDTH    = 300;
    
    /**
     * Default frame height
     */
    private static final int FRAME_HEIGHT   = 200;
    
    /**
     * X coordinate of the frame default origin point
     */
    private static final int FRAME_X_ORIGIN = 150;
    
    /**
     * Y coordinate of the frame default origin point
     */
    private static final int FRAME_Y_ORIGIN = 250;

    /**
     * Default width for buttons
     */
    private static final int BUTTON_WIDTH  = 60;
     
    /**
     * Default height for buttons
     */
    private static final int BUTTON_HEIGHT = 30;

    /**
     * The GUI button for Cancel
     */
    private Button cancelButton;
    
    
    /**
     * The GUI button for OK
     */
    private Button okButton;
    
    /**
     * The TextField object for the user to enter a line
     */
    TextField inputLine;

//----------------------------------
//    Constructors
//----------------------------------
                                
    /**
     * Default constructor
     */
    public MySecondFrame()
    {
        //set the frame properties
        setSize      (FRAME_WIDTH, FRAME_HEIGHT);
        setResizable (false);
        setTitle     ("Program MyFirstFrame");
        setLocation  (FRAME_X_ORIGIN, FRAME_Y_ORIGIN);
        setLayout    (null);
        
        //create and place two buttons on the frame
        okButton = new Button("OK");
        okButton.setBounds(100, 150, BUTTON_WIDTH, BUTTON_HEIGHT);
        add(okButton);
        
        cancelButton = new Button("CANCEL");
        cancelButton.setBounds(170, 150, BUTTON_WIDTH, BUTTON_HEIGHT);
        add(cancelButton);
  
        //register this frame as an action listener of the two buttons
        cancelButton.addActionListener(this);
        okButton.addActionListener(this);
        
        inputLine = new TextField();
        inputLine.setBounds(90, 50, 130, 25);
        add(inputLine);
        
        inputLine.addActionListener(this);
        
        //register a ProgramTerminator object as the window listener of this frame
        addWindowListener(new ProgramTerminator());
    }
   
///-------------------------------------------------
//      Public Methods:
// 
//          void    actionPerformed   (   ActionEvent        )
//
//------------------------------------------------
                                
    /**
     * Standard method to respond the action event.
     * 
     * @param event the ActionEvent object
     *
     */
    public void actionPerformed(ActionEvent event) 
    {
        if (event.getSource() instanceof Button) {
           Button clickedButton = (Button) event.getSource();
         
           if (clickedButton == cancelButton) {
              setTitle("You clicked CANCEL");
           }
           else { //the event source must be okButton
              setTitle("You clicked OK");
           }
        }
        else { //the event source is inputLine
           setTitle("You entered '" + inputLine.getText() + "'");
        }
    }
   
}